#!/usr/bin/env python

from micropython.objectset import ObjectSet, combine_mapping_dicts

# Test storage.

o1 = ObjectSet()
o1.add("a")
o1.add("b")
o1.add("c")
print "o1 =", o1

# Test storage with associated data.

o2 = ObjectSet()
o2.add("b")
o2["c"] = ["x"]
o2.add("d")
o2["d"].update(set(["p", "q"]))
print "o2 =", o2

print "o1 == o2", o1 == o2
print "o1 != o2", o1 != o2
assert o1 != o2

# Test merging.

o12 = o1.merge(o2)
print "o1 =", o1
print "o2 =", o2
print "o12 =", o12

o12_keys = o12.keys()
o12_keys.sort()
print "o12_keys =", o12_keys
assert o12_keys == ["a", "b", "c", "d"]

# Test copying.

o1_copy = ObjectSet(o1)
print "o1 =", o1
print "o1_copy =", o1_copy
print "o1 == o1_copy", o1 == o1_copy
assert o1 == o1_copy

# Test updating.

o1_copy.update(o2)
print "o1_copy =", o1_copy
print "o1 != o1_copy", o1 != o1_copy
print "o12 == o1_copy", o12 == o1_copy
assert o1 != o1_copy
assert o12 == o1_copy

o3 = ObjectSet()
o3.add("c")
o3["c"].add("y")
print "o3 =", o3

# Test combining.

d1 = {'a' : [ObjectSet(['f', 'g']), ObjectSet(['f', 'h'])]}
d2 = {'a' : [ObjectSet(['f']), ObjectSet(['e', 'f', 'g'])]}
d3 = combine_mapping_dicts(d1, d2)
print "d1 =", d1
print "d2 =", d2
print "d3 =", d3
assert d3["a"] == [ObjectSet(['f', 'g']), ObjectSet(['f', 'h']), ObjectSet(['e', 'f', 'g']), ObjectSet(['e', 'f', 'g', 'h'])]

# Test combining with empty sets.

d4 = {'a' : None}
d5 = combine_mapping_dicts(d1, d4)
print "d4 =", d4
print "d5 =", d5
assert d5 == d1

# vim: tabstop=4 expandtab shiftwidth=4
